(ns org.aplex.mailersend.core
  (:require
   [ajax.core :refer [json-request-format json-response-format]]
   [org.aplex.helpers.interface :as h]))

(def version "v1")
(def api-config (atom {:api-host "https://api.mailersend.com/"
                       :api-key (h/get-env "MAILERSENDER_API_KEY" "NO API KEY SUPPLIED")}))

(def default-authed-payload {:headers {"Authorization" (str "Bearer " (:api-key @api-config))
                                       "content-type" "application/json"}})

(defn init-config [cfg]
  (reset! api-config (merge @api-config cfg)))

(defn build-url [path]
  (str (:api-host @api-config) version path))

(defn send-email [email]
  (merge default-authed-payload
         {:uri (build-url "/email")
          :method :post
          :format (json-request-format)
          :response-format (json-response-format {:keywords? true})
          :keywords? true
          :params email}))

(defn list-domains []
  (merge default-authed-payload
         {:uri (build-url "/domains")
          :method :get
          :format (json-request-format)
          :response-format (json-response-format {:keywords? true})
          :keywords? true}))

(defn fetch-domain [domain-id]
  (merge default-authed-payload
         {:uri (build-url (str "/domains/" domain-id))
          :method :get
          :format (json-request-format)
          :response-format (json-response-format {:keywords? true})
          :keywords? true}))

(comment (send-email {:to ""}))
