(ns org.aplex.rest-stability-ai.core
  (:require [org.aplex.helpers.interface :as h]))

(def version "v1")
(def api-config (atom {:api-host "https://api.stability.ai"
                       :api-key (h/get-env "STABILITY_API_KEY" "NO API KEY SUPPLIED")}))

(def default-authed-payload {:headers {"Authorization" (str "Bearer " (-> @api-config :api-key))
                                       "content-type" "application/json"}})

(defn init-config [cfg]
  (reset! api-config (merge @api-config cfg)))

(defn build-url [path]
  (str (-> @api-config :api-host) path))

(defn fetch-user-account []
  (merge default-authed-payload
         {:uri (build-url "/v1/user/account")
          :method :get
          }))

(defn fetch-user-balance []
  (merge default-authed-payload
         {:uri (build-url "/v1/user/balance")
          :method :get
          :format :json
          }))

(defn fetch-available-engines []
  (merge default-authed-payload
         {:uri (build-url "/v1/engines/list")
          :method :get
          :format :json
          }))

(defn fetch-generation-text-to-image [required optional]
  (merge default-authed-payload
         {:uri (build-url "/v1/user/balance")
          :method :post
          :format :json
          :response-format :json
          :params {:text_prompts [{:text "A wooden hand crafted light house"
                                   :weight 0.5}]}
          }))


