(ns org.aplex.stability-ai.core
  (:require [org.aplex.helpers.interface :as h]))

(def version "v1")
(def api-config (atom {:api-host "https://api.stability.ai"
                       :api-key (h/get-env "STABILITY_API_KEY" "NO API KEY SUPPLIED")}))

(def api-host "https://api.stability.ai")
(def api-key (h/get-env "STABILITY_API_KEY" "NO API KEY SUPPLIED"))

(def default-authed-payload {:headers {"Authorization" (str "Bearer " api-key)
                                       "content-type" "application/json"}})

(defn init-config [cfg]
  (reset! api-config (merge @api-config cfg)))

(defn build-url [path]
  (str (:api-host api-config) "/" version path))

(defn fetch-user-account []
  (merge default-authed-payload 
         {:url (build-url "/v1/user/account")
          :handler prn}))

(defn fetch-user-balance []
  (merge default-authed-payload 
         {:url (build-url "/v1/user/balance")
          :handler prn}))

(defn fetch-generation-text-to-image [body]
  (merge default-authed-payload 
         {:url (build-url "/v1/user/balance")
          :method :post
          :format :json
          :response-format :json
          :params body
          :handler prn}))


